require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_xprinter',
  dscmeta_resource_friendly_name: 'xPrinter',
  dscmeta_resource_name: 'xPrinter',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'xPrinterManagement',
  dscmeta_module_version: '1.0.0.2',
  docs: 'The DSC xPrinter resource type.
         Automatically generated from version 1.0.0.2',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_comment: {
      type: 'Optional[String]',
      desc: 'Specifies the text to add to the Comment field for the specified printer',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_portname: {
      type: 'String',
      desc: 'Specifies the name of the port used or created for the printer',


      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',

      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_drivername: {
      type: 'String',
      desc: 'Specifies the name of the printer driver for the printer',


      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'present', 'Absent', 'absent']]",
      desc: ' ',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_sharename: {
      type: 'Optional[String]',
      desc: 'Specifies the share name of the printer',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_name: {
      type: 'String',
      desc: 'Specifies the name of the printer',

      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_location: {
      type: 'Optional[String]',
      desc: 'Specifies the location of the printer',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_published: {
      type: 'Optional[Boolean]',
      desc: 'Specifies whether or not the printer is published in the network directory service',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
  },
)
