require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_xprinterdriver',
  dscmeta_resource_friendly_name: 'xPrinterDriver',
  dscmeta_resource_name: 'xPrinterDriver',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'xPrinterManagement',
  dscmeta_module_version: '1.0.0.2',
  docs: 'The DSC xPrinterDriver resource type.
         Automatically generated from version 1.0.0.2',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_drivername: {
      type: 'String',
      desc: 'Specifies the name of the printer driver',

      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_infpath: {
      type: 'Optional[String]',
      desc: 'Specifies the path to the printer driver INF file in the driver store. INF files contain information about the printer and the printer driver',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',

      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_environment: {
      type: "Optional[Enum['x86', 'x64']]",
      desc: 'Specifies the printer driver environment',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'present', 'Absent', 'absent']]",
      desc: ' ',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
